<?xml version="1.0"?>
<!-- 

  Extract the paths of images contained in each of the documents listed in the input document.
  The input documents must contain a list of 'uri' elements in a root 'uri' element.
  The paths are all loaded as a '|' separated list in a property called 'image.paths'.
  Paths starting with '/uri/' are copied as is.
  Paths starting with '/' are decoded and copied.
  Paths starting with 'http://' are ignored.
  Other paths are decoded and resolved so they become relative to the document's folder.

  @author Jean-Baptiste Reure
  @version 10 April 2012

  Copyright (C) 2009 Weborganic Systems Pty. Ltd.
  
 -->
<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:xs="http://www.w3.org/2001/XMLSchema"
  xmlns:psf="http://www.pageseeder.com/function"
  xmlns:dec="java:java.net.URLDecoder">

  <xsl:param name="input-base" />
  <xsl:param name="output-base" />
	<xsl:param name="siteprefix" select="''" />

  <xsl:output encoding="UTF-8" method="text" />

  <xsl:template match="/uris">
    <xsl:variable name="list">
	      <xsl:for-each select="uri[starts-with(behavior, 'standard')]">
	        <xsl:variable name="doc" select="document(concat(replace($input-base, '\\', '/'), '/', decodedpath))" />
	        <xsl:variable name="new-url" select="concat(replace($output-base, '\\', '/'), '/', decodedpath)" />
          <xsl:apply-templates select="$doc//graphic">
            <xsl:with-param name="urifolder" select="string-join(tokenize(current()/path, '/')[position() != last()], '/')" tunnel="yes" />
          </xsl:apply-templates>
	      </xsl:for-each>
    </xsl:variable>
    <xsl:text>image.paths=</xsl:text>
    <xsl:value-of select="replace($list, '\|$', '')" />
    <xsl:text>&#xA;</xsl:text>
	</xsl:template>

	<xsl:template match="graphic">
    <xsl:param name="urifolder"    tunnel="yes" />
		<xsl:choose>
		  <!-- may need to fix file ext -->
      <xsl:when test="starts-with(@src,concat($siteprefix,'/uri/'))">
				<xsl:value-of select="@src" />|<xsl:text/>
			</xsl:when>
			<xsl:when test="starts-with(@src,'http://')" />
			<xsl:when test="starts-with(@src,'/')">
				<xsl:value-of select="dec:decode(@src,'UTF-8')" />|<xsl:text/>
			</xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="dec:decode(psf:resolve-relative-path(@src,$urifolder),'UTF-8')" />|<xsl:text/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:function name="psf:resolve-relative-path" as="xs:string">
    <xsl:param name="path" />
    <xsl:param name="base" />
    <xsl:choose>
      <xsl:when test="starts-with($path, '../')">
        <xsl:variable name="all-folders" select="tokenize($base, '/')[.]" />
        <xsl:variable name="new-base" select="concat('/', string-join($all-folders[position() != last()], '/'))"/>
        <xsl:value-of select="psf:resolve-relative-path(substring-after($path,'../'), $new-base)" />
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="concat($base,'/',$path)" />
      </xsl:otherwise>
    </xsl:choose>
  </xsl:function>

</xsl:stylesheet>

